@@ -1,9 +1,9 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
-# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -12,16 +12,16 @@
 ##############################################################################
 """Deprecated text index. Please use ZCTextIndex instead.
 
-$Id: TextIndex.py 40192 2005-11-17 13:20:58Z mj $
+$Id: TextIndex.py 41190 2006-01-08 10:22:28Z andreasjung $
 """
 
 import operator, warnings
 import re
 from cgi import escape
 from types import *
-
+from logging import getLogger
 from Globals import Persistent, DTMLFile
-from zLOG import LOG, ERROR
+
 from Acquisition import Implicit
 from OFS.SimpleItem import SimpleItem
 from BTrees.IOBTree import IOBTree
@@ -39,6 +39,7 @@ from Products.PluginIndexes.interfaces import ITextIndex
 
 from Lexicon import Lexicon
 
+LOG = getLogger('TextIndex')
 
 class Op:
     def __init__(self, name):
@@ -376,9 +377,8 @@ class TextIndex(Persistent, Implicit, SimpleItem):
         for wid in wids:
             widScores = get(wid, None)
             if widScores is None:
-                LOG('TextIndex', ERROR,
-                    'unindex_object tried to unindex nonexistent'
-                    ' document, wid  %s, %s' % (i,wid))
+                LOG.error('unindex_object tried to unindex nonexistent'
+                          ' document, wid  %s, %s' % (i,wid))
                 continue
             if type(widScores) is TupleType:
                 del index[wid]
@@ -394,9 +394,8 @@ class TextIndex(Persistent, Implicit, SimpleItem):
                     else:
                         del index[wid]
                 except (KeyError, IndexError, TypeError):
-                    LOG('TextIndex', ERROR,
-                        'unindex_object tried to unindex nonexistent'
-                        ' document %s' % str(i))
+                    LOG.error('unindex_object tried to unindex nonexistent'
+                              ' document %s' % str(i))
 
     def __getitem__(self, word):
         """Return an InvertedIndex-style result "list"
