@@ -24,7 +24,7 @@ The twist is that the portal object itself is *not* created
 by the PortalTestCase class! Subclasses must make sure
 getPortal() returns a usable portal object to the setup code.
 
-$Id: PortalTestCase.py 30565 2005-05-30 22:07:11Z shh $
+$Id: PortalTestCase.py 77006 2007-06-24 10:25:28Z shh $
 """
 
 import base
@@ -100,7 +100,10 @@ class PortalTestCase(base.TestCase):
             self.portal.clearCurrentSkin()
         else: # CMF 1.4
             self.portal._v_skindata = None
-        self.portal.setupCurrentSkin()
+        try:
+            self.portal.setupCurrentSkin(self.app.REQUEST)
+        except TypeError:
+            self.portal.setupCurrentSkin()
 
     # Portal interface
 
