@@ -13,7 +13,7 @@
 ##############################################################################
 """Form and Widget specific 'browser' ZCML namespace interfaces
 
-$Id: metadirectives.py 70363 2006-09-25 12:34:15Z yuppie $
+$Id: metadirectives.py 67630 2006-04-27 00:54:03Z jim $
 """
 __docformat__ = 'restructuredtext'
 
@@ -22,8 +22,8 @@ from zope.configuration.fields import GlobalObject, GlobalInterface
 from zope.configuration.fields import Tokens, Path, Bool, PythonIdentifier
 from zope.configuration.fields import MessageID
 from zope.schema import Text, TextLine, Id
-from zope.app.component.fields import LayerField
-from zope.app.security.fields import Permission
+from zope.security.zcml import Permission
+from zope.app.component.back35 import LayerField
 from zope.app.publisher.browser.fields import MenuField
 
 class ICommonInformation(Interface):
